@@ -28,7 +28,7 @@ const arrayForWordSize = (ws: number, n: number) => {
 };
 """
 import os
-import json
+import uuid
 import numpy as np
 import logging
 
@@ -100,7 +100,7 @@ def decode_from_annotation(from_name, results):
     for result in results:
         key = 'brushlabels' if result['type'].lower() == 'brushlabels' else \
             ('labels' if result['type'].lower() == 'labels' else None)
-        if key is None:
+        if key is None or 'rle' not in result:
             continue
 
         rle = result['rle']
@@ -122,7 +122,10 @@ def decode_from_annotation(from_name, results):
 def save_brush_images_from_annotation(task_id, annotation_id, completed_by,
                                       from_name, results, out_dir, out_format='numpy'):
     layers = decode_from_annotation(from_name, results)
-    email = completed_by.get('email', 'none')
+    if isinstance(completed_by, dict):
+        email = completed_by.get('email', '')
+    else:
+        email = str(completed_by)
     email = "".join(x for x in email if x.isalnum() or x == '@' or x == '.')  # sanitize filename
 
     for name in layers:
@@ -180,7 +183,7 @@ def encode_rle(arr, wordsize=8, rle_sizes=[3, 4, 8, 16]):
     """ Encode a 1d array to rle
 
 
-    :param arr : flattened np.array from a 4d image (R, G, B, alpha)
+    :param arr: flattened np.array from a 4d image (R, G, B, alpha)
     :type arr: np.array
     :param wordsize: wordsize bits for decoding, default is 8
     :type wordsize: int
@@ -304,7 +307,7 @@ def encode_rle(arr, wordsize=8, rle_sizes=[3, 4, 8, 16]):
     return rle
 
 
-def mask2rle(contours, contour_id, img_width, img_height):
+def contour2rle(contours, contour_id, img_width, img_height):
     """
     :param contours:  list of contours
     :type contours: list
@@ -314,7 +317,7 @@ def mask2rle(contours, contour_id, img_width, img_height):
     :type img_width: int
     :param img_height: image shape height
     :type img_height: int
-    :return:
+    :return: list of ints in RLE format 
     """
     import cv2  # opencv
     mask_im = np.zeros((img_width, img_height, 4))
@@ -322,3 +325,82 @@ def mask2rle(contours, contour_id, img_width, img_height):
     rle_out = encode_rle(mask_contours.ravel().astype(int))
     return rle_out
 
+
+def mask2rle(mask):
+    """ Convert mask to RLE
+    
+    :param mask: uint8 or int np.array mask with len(shape) == 2 like grayscale image
+    :return: list of ints in RLE format 
+    """
+    assert len(mask.shape) == 2, 'mask must be 2D np.array'
+    assert mask.dtype == np.uint8 or mask.dtype == int, 'mask must be uint8 or int'
+    array = mask.ravel()
+    array = np.repeat(array, 4)  # must be 4 channels 
+    rle = encode_rle(array)
+    return rle
+    
+    
+def image2rle(path):
+    """ Convert image to RLE
+
+    1. Read image as grayscale
+    2. Flatten to 1d array
+    3. Threshold > 128
+    4. Encode
+    
+    :return: list of ints in RLE format 
+    """
+    with Image.open(path).convert('L') as image:
+        mask = np.array((np.array(image) > 128) * 255, dtype=np.uint8)
+        array = mask.ravel()
+        array = np.repeat(array, 4)
+        rle = encode_rle(array)
+        return rle, image.size[0], image.size[1]
+
+
+def image2annotation(path, label_name, from_name, to_name, ground_truth=False, model_version=None, score=None):
+    """ Convert image with mask to brush RLE annotation
+
+    :param path: path to image with mask (jpg, png)
+    :param label_name: label name from labeling config (<Label>)
+    :param from_name: brush tag name (<BrushLabels>)
+    :param to_name: image tag name (<Image>)
+    :param ground_truth: ground truth annotation true/false
+    :param model_version: any string, only for predictions
+    :param score: model score as float, only for predictions
+    
+    :return: dict with Label Studio Annotation or Prediction (Pre-annotation)
+    """
+    rle, width, height = image2rle(path)
+    result = {
+        "result": [
+            {
+                "id": str(uuid.uuid4())[0:8],
+                "type": "brushlabels",
+                "value": {
+                    "rle": rle,
+                    "format": "rle",
+                    "brushlabels": [
+                        label_name
+                    ]
+                },
+                "origin": "manual",
+                "to_name": to_name,
+                "from_name": from_name,
+                "image_rotation": 0,
+                "original_width": width,
+                "original_height": height
+            }
+        ],
+    }
+
+    # prediction
+    if model_version:
+        result["model_version"] = model_version
+        result["score"] = score
+
+    # annotation
+    else:
+        result["ground_truth"] = ground_truth
+
+    return result
