@@ -8,6 +8,7 @@ import urllib
 import numpy as np
 import wave
 import shutil
+import argparse
 
 from operator import itemgetter
 from PIL import Image
@@ -18,6 +19,11 @@ from nltk.tokenize import WhitespaceTokenizer
 logger = logging.getLogger(__name__)
 
 
+class ExpandFullPath(argparse.Action):
+    def __call__(self, parser, namespace, values, option_string=None):
+        setattr(namespace, self.dest, os.path.abspath(os.path.expanduser(values)))
+
+
 def tokenize(text):
     tok_start = 0
     out = []
@@ -87,7 +93,8 @@ def _get_upload_dir(project_dir=None, upload_dir=None):
     return upload_dir
 
 
-def download(url, output_dir, filename=None, project_dir=None, return_relative_path=False, upload_dir=None):
+def download(url, output_dir, filename=None, project_dir=None, return_relative_path=False, upload_dir=None,
+             download_resources=True):
     is_local_file = url.startswith('/data/') and '?d=' in url
     is_uploaded_file = url.startswith('/data/upload')
 
@@ -95,8 +102,9 @@ def download(url, output_dir, filename=None, project_dir=None, return_relative_p
         upload_dir = _get_upload_dir(project_dir, upload_dir)
         filename = url.replace('/data/upload/', '')
         filepath = os.path.join(upload_dir, filename)
-        logger.debug('Copy {filepath} to {output_dir}'.format(filepath=filepath, output_dir=output_dir))
-        shutil.copy(filepath, output_dir)
+        logger.debug(f'Copy {filepath} to {output_dir}'.format(filepath=filepath, output_dir=output_dir))
+        if download_resources:
+            shutil.copy(filepath, output_dir)
         if return_relative_path:
             return os.path.join(os.path.basename(output_dir), filename)
         return filepath
@@ -117,10 +125,11 @@ def download(url, output_dir, filename=None, project_dir=None, return_relative_p
     filepath = os.path.join(output_dir, filename)
     if not os.path.exists(filepath):
         logger.info('Download {url} to {filepath}'.format(url=url, filepath=filepath))
-        r = requests.get(url)
-        r.raise_for_status()
-        with io.open(filepath, mode='wb') as fout:
-            fout.write(r.content)
+        if download_resources:
+            r = requests.get(url)
+            r.raise_for_status()
+            with io.open(filepath, mode='wb') as fout:
+                fout.write(r.content)
     if return_relative_path:
         return os.path.join(os.path.basename(output_dir), filename)
     return filepath
@@ -189,3 +198,17 @@ def get_polygon_bounding_box(x, y):
 
     x1, y1, x2, y2 = min(x), min(y), max(x), max(y)
     return [x1, y1, x2 - x1, y2 - y1]
+
+
+def _get_annotator(item, default=None, int_id=False):
+    """ Get annotator id or email from annotation
+    """
+    annotator = item['completed_by']
+    if isinstance(annotator, dict):
+        annotator = annotator.get('email', default)
+        return annotator
+
+    if isinstance(annotator, int) and int_id:
+        return annotator
+
+    return str(annotator)
